#!/usr/bin/env bash
#
# Skinny wrapper environment script for MIRS (run_mirs.pl) under CSPP with singularity
#
# The location of the singularity container is required.
# So I am going to require CSPP_MIRS_HOME to find it.
#
# exit when the first non-zero exit status is encountered
set -e

# check installation home and chdir to it
if [[ -z $CSPP_MIRS_HOME ]]; then
  echo "Must provide CSPP_MIRS_HOME in environment. See cspp_mirs_env.sh" 1>&2
  exit 1
fi

# convert $CSPP_MIRS_HOME to canonical form
export CSPP_MIRS_HOME=$(readlink -f $CSPP_MIRS_HOME)

# check for singularity 
$CSPP_MIRS_HOME/scripts/sing_test.bash

# name the container
mirs=$CSPP_MIRS_HOME/mirs.sif

# use readlink -f to track hidden links needed to grok bind string for singularity container of app
#readlinked=
#dirlist=$(singularity --silent exec --home=$PWD --bind=$CSPP_MIRS_HOME $mirs Rscript $CSPP_MIRS_HOME/scripts/dirlist_mirs.R $@)
#for mydir in $dirlist; do export readlinked=$readlinked,$(readlink -f $mydir); done
#bind=$(singularity --silent exec --home=$PWD --bind=$CSPP_MIRS_HOME $mirs Rscript $CSPP_MIRS_HOME/scripts/bind_wrangle.R $readlinked)
bind=$($CSPP_MIRS_HOME/scripts/bind_wrangle.bash $@)

# run run_mirs.pl in the singularity container built for mirs with grokked $bind
singularity --silent exec --home $PWD $bind $mirs perl $CSPP_MIRS_HOME/scripts/run_mirs.pl $@

# Done
echo Done.
